@@ -5,9 +5,9 @@
     'Package:  xergm\n', 
     'Version:  ', desc$Version, '\n', 
     'Date:     ', desc$Date, '\n', 
-    'Authors:  Philip Leifeld (Eawag and University of Bern)\n',
+    'Authors:  Philip Leifeld (University of Glasgow)\n',
     '          Skyler J. Cranmer (The Ohio State University)\n',
-    '          Bruce A. Desmarais (Penn State University)', 
+    '          Bruce A. Desmarais (Pennsylvania State University)', 
     '\n\nPlease cite the xergm package in your publications ', 
     '-- see citation("xergm").\n'
   )
